Molpro
======

Molpro is a complete system of ab initio programs for molecular electronic structure calculations.

About Molpro
------------
Molpro is a software package used for accurate ab-initio quantum chemistry calculations. More information can be found at the [official webpage](http://www.molpro.net/)![external](../../../img/external.png).

License
-------
Molpro software package is available only to users that have a valid license. Please contact support to enable access to Molpro if you have a valid license appropriate for running on our cluster (eg. academic research group licence, parallel execution).

To run Molpro, you need to have a valid license token present in " $HOME/.molpro/token". You can download the token from [Molpro website](https://www.molpro.net/licensee/?portal=licensee)![external](../../../img/external.png).

Installed version
-----------------
Currently on Anselm is installed version 2010.1, patch level 45, parallel version compiled with Intel compilers and Intel MPI.

Compilation parameters are default:

|Parameter|Value|
|---|---|
|max number of atoms|200|
|max number of valence orbitals|300|
|max number of basis functions|4095|
|max number of states per symmmetry|20|
|max number of state symmetries|16|
|max number of records|200|
|max number of primitives|maxbfn x [2]|

Running
------
Molpro is compiled for parallel execution using MPI and OpenMP. By default, Molpro reads the number of allocated nodes from PBS and launches a data server on one node. On the remaining allocated nodes, compute processes are launched, one process per node, each with 16 threads. You can modify this behavior by using -n, -t and helper-server options. Please refer to the [Molpro documentation](http://www.molpro.net/info/2010.1/doc/manual/node9.html)![external](../../../img/external.png) for more details.

!!! Note "Note"
	The OpenMP parallelization in Molpro is limited and has been observed to produce limited scaling. We therefore recommend to use MPI parallelization only. This can be achieved by passing option  mpiprocs=16:ompthreads=1 to PBS.

You are advised to use the -d option to point to a directory in [SCRATCH filesystem](../../storage/storage/). Molpro can produce a large amount of temporary data during its run, and it is important that these are placed in the fast scratch filesystem.

### Example jobscript

```bash
    #PBS -A IT4I-0-0
    #PBS -q qprod
    #PBS -l select=1:ncpus=16:mpiprocs=16:ompthreads=1

    cd $PBS_O_WORKDIR

    # load Molpro module
    module add molpro

    # create a directory in the SCRATCH filesystem
    mkdir -p /scratch/$USER/$PBS_JOBID

    # copy an example input
    cp /apps/chem/molpro/2010.1/molprop_2010_1_Linux_x86_64_i8/examples/caffeine_opt_diis.com .

    # run Molpro with default options
    molpro -d /scratch/$USER/$PBS_JOBID caffeine_opt_diis.com

    # delete scratch directory
    rm -rf /scratch/$USER/$PBS_JOBID
```